/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                              **** CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2009 - 2010
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2010_Alum_cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2010_Alum_cuest.txt
/*         as como el archivo Excale03_2010_Alum_cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2010_Alum_cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2010_Alum_cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 18 DE MAYO DEL 2012
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2010_Alum_cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "UP"      = "Urbano Pblico"
                       "RP"      = "Rural Pblico"
                       "EI"      = "Educacin Indgena"
                       "CC"      = "Cursos Comunitarios"
                       "UPV"     = "Privados"
                       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edadF       99        = "Respuesta omitida";
     VALUE edadcF      1         = "Once aos o menos"
                       2         = "Doce aos"
                       3         = "Trece aos"
                       4         = "Catorce aos o ms"
                       9         = "Respuesta omitida";
     VALUE edadnF      1         = "Edad normativa"
                       2         = "Extra-edad"
                       9         = "Respuesta omitida";
     VALUE edad_acF    10        = "10 aos"
                       11        = "11 aos"
                       12        = "12 aos"
                       13        = "13 aos"
                       14        = "14 aos"
                       15        = "15 aos o ms"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE mes_nacF    1         = "Enero"
                       2         = "Febrero"
                       3         = "Marzo"
                       4         = "Abril"
                       5         = "Mayo"
                       6         = "Junio"
                       7         = "Julio"
                       8         = "Agosto"
                       9         = "Septiembre"
                       10        = "Octubre"
                       11        = "Noviembre"
                       12        = "Diciembre"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE docenteF    99999     = "Respuesta omitida";
     VALUE AP1_2F      1         = "S"
                       0         = "No"
                       2         = "No lo s"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP3_7F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP008F      0         = "Ninguno de los dos"
                       1         = "Slo mi pap"
                       2         = "Slo mi mam"
                       3         = "Los dos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP9_10F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP011F      0         = "S"
                       1         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP012F      0         = "Nunca"
                       1         = "Una vez"
                       2         = "Varias veces"
                       3         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP013F      0         = "El espaol"
                       1         = "Una lengua indgena"
                       2         = "Un idioma extranjero"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP14_16F    0         = "Casi nunca"
                       1         = "A veces"
                       2         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP017F      0         = "No"
                       1         = "Slo con mi mam"
                       2         = "Slo con mi pap"
                       3         = "Con los dos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP018F      0         = "No"
                       1         = "Slo mi mam"
                       2         = "Slo mi pap"
                       3         = "Los dos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP019F      3         = "No"
                       2         = "Slo mi mam"
                       1         = "Slo mi pap"
                       0         = "Los dos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP020F      0         = "No"
                       1         = "Slo con mi mam"
                       2         = "Slo con mi pap"
                       3         = "Con los dos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP021F      0         = "Casi nunca"
                       1         = "A veces"
                       2         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP022F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP023F      1         = "Muy pocas"
                       2         = "Algunas"
                       3         = "Todas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP24_28F    0         = "Casi nunca"
                       1         = "A veces"
                       2         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP29_36F    2         = "Casi nunca"
                       1         = "A veces"
                       0         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP37_43F    0         = "Casi nunca"
                       1         = "A veces"
                       2         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP044F      3         = "S, mucho"
                       2         = "Ms o menos"
                       1         = "Poco"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP45_46F    0         = "Casi nunca"
                       1         = "A veces"
                       2         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP047F      2         = "S"
                       1         = "Ms o menos"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP048F      2         = "Casi nunca"
                       1         = "A veces"
                       0         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP049F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP50_52F    2         = "S"
                       1         = "Ms o menos"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP053F      0         = "S"
                       1         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AP054F      2         = "Casi nunca"
                       1         = "A veces"
                       0         = "Siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
RUN;



DATA INEE.Excale03_2010_Alum_cuest;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            $7
       ENTEST             $6
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       MES_NAC            3
       W_ALU              8
       DOCENTE            5
       AP001              3
       AP002              3
       AP003              3
       AP004              3
       AP005              3
       AP006              3
       AP007              3
       AP008              3
       AP009              3
       AP010              3
       AP011              3
       AP012              3
       AP013              3
       AP014              3
       AP015              3
       AP016              3
       AP017              3
       AP018              3
       AP019              3
       AP020              3
       AP021              3
       AP022              3
       AP023              3
       AP024              3
       AP025              3
       AP026              3
       AP027              3
       AP028              3
       AP029              3
       AP030              3
       AP031              3
       AP032              3
       AP033              3
       AP034              3
       AP035              3
       AP036              3
       AP037              3
       AP038              3
       AP039              3
       AP040              3
       AP041              3
       AP042              3
       AP043              3
       AP044              3
       AP045              3
       AP046              3
       AP047              3
       AP048              3
       AP049              3
       AP050              3
       AP051              3
       AP052              3
       AP053              3
       AP054              3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
       W_FSTR81           8
       W_FSTR82           8
       W_FSTR83           8
       W_FSTR84           8
       W_FSTR85           8
       W_FSTR86           8
       W_FSTR87           8
       W_FSTR88           8
       W_FSTR89           8
       W_FSTR90           8
       W_FSTR91           8
       W_FSTR92           8
       W_FSTR93           8
       W_FSTR94           8
       W_FSTR95           8
       W_FSTR96           8
       W_FSTR97           8
       W_FSTR98           8
       W_FSTR99           8
       W_FSTR100          8
 ;





 INFILE alum MISSOVER LINESIZE = 1257;
   INPUT
       NACIONAL             1 - 1
       ESCUELA              2 - 5
       ID_ENT               6 - 7
       NOM_ENT              8 - 26
       ID_MOD              27 - 27
       MOD                 28 - 31
       ESTRATO             32 - 38
       ENTEST              39 - 44
       ALUMNO              45 - 50
       ID_INSTR            51 - 66
       SEXO                67 - 67
       EDAD                68 - 78
       EDADC               79 - 79
       EDADN               80 - 80
       EDAD_AC             81 - 82
       MES_NAC             83 - 84
       W_ALU               85 - 95
       DOCENTE             96 - 100
       AP001              101 - 101
       AP002              102 - 102
       AP003              103 - 103
       AP004              104 - 104
       AP005              105 - 105
       AP006              106 - 106
       AP007              107 - 107
       AP008              108 - 108
       AP009              109 - 109
       AP010              110 - 110
       AP011              111 - 111
       AP012              112 - 112
       AP013              113 - 113
       AP014              114 - 114
       AP015              115 - 115
       AP016              116 - 116
       AP017              117 - 117
       AP018              118 - 118
       AP019              119 - 119
       AP020              120 - 120
       AP021              121 - 121
       AP022              122 - 122
       AP023              123 - 123
       AP024              124 - 124
       AP025              125 - 125
       AP026              126 - 126
       AP027              127 - 127
       AP028              128 - 128
       AP029              129 - 129
       AP030              130 - 130
       AP031              131 - 131
       AP032              132 - 132
       AP033              133 - 133
       AP034              134 - 134
       AP035              135 - 135
       AP036              136 - 136
       AP037              137 - 137
       AP038              138 - 138
       AP039              139 - 139
       AP040              140 - 140
       AP041              141 - 141
       AP042              142 - 142
       AP043              143 - 143
       AP044              144 - 144
       AP045              145 - 145
       AP046              146 - 146
       AP047              147 - 147
       AP048              148 - 148
       AP049              149 - 149
       AP050              150 - 150
       AP051              151 - 151
       AP052              152 - 152
       AP053              153 - 153
       AP054              154 - 154
       WVARSTRR           155 - 157
       W_FSTR1            158 - 168
       W_FSTR2            169 - 179
       W_FSTR3            180 - 190
       W_FSTR4            191 - 201
       W_FSTR5            202 - 212
       W_FSTR6            213 - 223
       W_FSTR7            224 - 234
       W_FSTR8            235 - 245
       W_FSTR9            246 - 256
       W_FSTR10           257 - 267
       W_FSTR11           268 - 278
       W_FSTR12           279 - 289
       W_FSTR13           290 - 300
       W_FSTR14           301 - 311
       W_FSTR15           312 - 322
       W_FSTR16           323 - 333
       W_FSTR17           334 - 344
       W_FSTR18           345 - 355
       W_FSTR19           356 - 366
       W_FSTR20           367 - 377
       W_FSTR21           378 - 388
       W_FSTR22           389 - 399
       W_FSTR23           400 - 410
       W_FSTR24           411 - 421
       W_FSTR25           422 - 432
       W_FSTR26           433 - 443
       W_FSTR27           444 - 454
       W_FSTR28           455 - 465
       W_FSTR29           466 - 476
       W_FSTR30           477 - 487
       W_FSTR31           488 - 498
       W_FSTR32           499 - 509
       W_FSTR33           510 - 520
       W_FSTR34           521 - 531
       W_FSTR35           532 - 542
       W_FSTR36           543 - 553
       W_FSTR37           554 - 564
       W_FSTR38           565 - 575
       W_FSTR39           576 - 586
       W_FSTR40           587 - 597
       W_FSTR41           598 - 608
       W_FSTR42           609 - 619
       W_FSTR43           620 - 630
       W_FSTR44           631 - 641
       W_FSTR45           642 - 652
       W_FSTR46           653 - 663
       W_FSTR47           664 - 674
       W_FSTR48           675 - 685
       W_FSTR49           686 - 696
       W_FSTR50           697 - 707
       W_FSTR51           708 - 718
       W_FSTR52           719 - 729
       W_FSTR53           730 - 740
       W_FSTR54           741 - 751
       W_FSTR55           752 - 762
       W_FSTR56           763 - 773
       W_FSTR57           774 - 784
       W_FSTR58           785 - 795
       W_FSTR59           796 - 806
       W_FSTR60           807 - 817
       W_FSTR61           818 - 828
       W_FSTR62           829 - 839
       W_FSTR63           840 - 850
       W_FSTR64           851 - 861
       W_FSTR65           862 - 872
       W_FSTR66           873 - 883
       W_FSTR67           884 - 894
       W_FSTR68           895 - 905
       W_FSTR69           906 - 916
       W_FSTR70           917 - 927
       W_FSTR71           928 - 938
       W_FSTR72           939 - 949
       W_FSTR73           950 - 960
       W_FSTR74           961 - 971
       W_FSTR75           972 - 982
       W_FSTR76           983 - 993
       W_FSTR77           994 - 1004
       W_FSTR78          1005 - 1015
       W_FSTR79          1016 - 1026
       W_FSTR80          1027 - 1037
       W_FSTR81          1038 - 1048
       W_FSTR82          1049 - 1059
       W_FSTR83          1060 - 1070
       W_FSTR84          1071 - 1081
       W_FSTR85          1082 - 1092
       W_FSTR86          1093 - 1103
       W_FSTR87          1104 - 1114
       W_FSTR88          1115 - 1125
       W_FSTR89          1126 - 1136
       W_FSTR90          1137 - 1147
       W_FSTR91          1148 - 1158
       W_FSTR92          1159 - 1169
       W_FSTR93          1170 - 1180
       W_FSTR94          1181 - 1191
       W_FSTR95          1192 - 1202
       W_FSTR96          1203 - 1213
       W_FSTR97          1214 - 1224
       W_FSTR98          1225 - 1235
       W_FSTR99          1236 - 1246
       W_FSTR100         1247 - 1257
 ;





 LABEL
       NACIONAL      = "Variable auxiliar para obtener promedios nacionales"
       ESCUELA       = "Identificador de la escuela"
       ID_ENT        = "Entidad federativa (identificador numrico)"
       NOM_ENT       = "Entidad federativa"
       ID_MOD        = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD           = "Estrato escolar o Modalidad educativa"
       ESTRATO       = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       ENTEST        = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       ALUMNO        = "Identificador del alumno"
       ID_INSTR      = "Identificador del cuadernillo de examen"
       SEXO          = "Sexo del alumno"
       EDAD          = "Edad del alumno al mes de mayo de 2010, en aos (al momento de la aplicacin)"
       EDADC         = "Edad del alumno al mes de mayo de 2010, codificada (al momento de la aplicacin)"
       EDADN         = "Edad normativa"
       EDAD_AC       = "Edad en aos cumplidos (al momento de la aplicacin)"
       MES_NAC       = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       W_ALU         = "Peso muestral o ponderador del alumno"
       DOCENTE       = "Identificador del docente que imparte clases al alumno"
       AP001         = "Tu mam sabe escribir?"
       AP002         = "T pap sabe escribir?"
       AP003         = "Alguien te lee cuentos en tu casa?"
       AP004         = "En tu casa tienes libros diferentes a los que usas en la escuela?"
       AP005         = "En las ltimas vacaciones, fuiste a alguna feria, fiesta de pueblo, exposicin, museo o al cine?"
       AP006         = "Sabes  usar una computadora?"
       AP007         = "Hay telfono en tu casa?"
       AP008         = "Alguno de tus paps tiene automvil?"
       AP009         = "Hay computadora en tu casa?"
       AP010         = "En tu casa tiene agua todos los das?"
       AP011         = "En tu casa duermen ms de tres personas en el mismo cuarto?"
       AP012         = "Te han llevado alguna vez de vacaciones?"
       AP013         = "Que aprendiste a hablar primero?"
       AP014         = "Alguien de tu familia est al pendiente de cmo te va en la escuela?"
       AP015         = "Alguien de tu familia se preocupa por que lleves el material que te piden en la escuela?"
       AP016         = "Alguien de tu familia te ayuda a hacer la tarea?"
       AP017         = "Hablas con tus paps de las cosas que te ensean en la escuela?"
       AP018         = "Tus paps juegan contigo?"
       AP019         = "Tus paps te regaan todo el tiempo?"
       AP020         = "Platicas con tus paps sobre lo que sientes?"
       AP021         = "Cundo llegas a tu casa te sientes contento?"
       AP022         = "Has reprobado algn ao?"
       AP023         = "Haces las tareas que tu maestra te deja?"
       AP024         = "Tu maestra(o) te ayuda a resolver tus dudas?"
       AP025         = "Revisan en clase las tareas, ejercicios e investigaciones que les deja al maestra(o)?"
       AP026         = "Tu maestra(o) explica bien?"
       AP027         = "Tu maestra(o) da ejemplos fciles para ayudarte a aprender?"
       AP028         = "Adems del pizarrn, libros y cuadernos, tu maestra(o) utiliza otros materiales para dar clase?"
       AP029         = "Qu tan seguido falta tu maestra(o) a clases?"
       AP030         = "Qu tan seguido llega tarde tu maestra(o)?"
       AP031         = "Tu maestra(o) deja solo a tu grupo en horas de clase?"
       AP032         = "Tu maestra(o) platica con otros adultos en horas de clase?"
       AP033         = "Hay personas que interrumpen las clases de tu grupo?"
       AP034         = "Tu maestra(o) los deja hacer lo que quieran mientras ella hace otras cosas?"
       AP035         = "Te aburres durante las clases porque no tienes trabajo que hacer?"
       AP036         = "Tu maestra(o) interrumpe sus clases por mala conducta de tus compaeros?"
       AP037         = "Tu maestra(o) hace que todos participen en la clase?"
       AP038         = "Tu maestra(o) te pide que te esfuerces por aprender?"
       AP039         = "Tu maestra(o) cree que puedes aprender lo que te ensea?"
       AP040         = "Tu maestra(o) cree que eres inteligente?"
       AP041         = "Tu maestra(o) te felicita cuando haces algo bien?"
       AP042         = "Tu maestra(o) platica contigo?"
       AP043         = "Tu maestra(o) te hace caso cuando le hablas?"
       AP044         = "Te gusta estar con tu maestra(o)?"
       AP045         = "Tu maestra(o) se preocupa por lo que te pasa?"
       AP046         = "Confas en tu maestra(o) para platicarles tus problemas?"
       AP047         = "los nios y nias de tu grupo se llevan bien?"
       AP048         = "Los nios de tu grupo se pelean cuando est la maestra(o)?"
       AP049         = "Tiene buenos amigos en tu saln?"
       AP050         = "Te gusta tu grupo?"
       AP051         = "Te gusta tu escuela?"
       AP052         = "Cundo ests en la escuela te sientes contento?"
       AP053         = "Te gustara cambiarte de escuela?"
       AP054         = "Te ocurren cosas en la escuela que te hacen sentir mal?"
       WVARSTRR      = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR81      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR82      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR83      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR84      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR85      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR86      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR87      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR88      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR89      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR90      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR91      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR92      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR93      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR94      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR95      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR96      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR97      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR98      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR99      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR100     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
 ;

 FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       ESTRATO            $char7.
       ENTEST             $char6.
       ALUMNO             5.
       ID_INSTR           $char16.
       SEXO               sexoF.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       MES_NAC            mes_nacF.
       DOCENTE            docenteF.
       AP001              AP1_2F.
       AP002              AP1_2F.
       AP003              AP3_7F.
       AP004              AP3_7F.
       AP005              AP3_7F.
       AP006              AP3_7F.
       AP007              AP3_7F.
       AP008              AP008F.
       AP009              AP9_10F.
       AP010              AP9_10F.
       AP011              AP011F.
       AP012              AP012F.
       AP013              AP013F.
       AP014              AP14_16F.
       AP015              AP14_16F.
       AP016              AP14_16F.
       AP017              AP017F.
       AP018              AP018F.
       AP019              AP019F.
       AP020              AP020F.
       AP021              AP021F.
       AP022              AP022F.
       AP023              AP023F.
       AP024              AP24_28F.
       AP025              AP24_28F.
       AP026              AP24_28F.
       AP027              AP24_28F.
       AP028              AP24_28F.
       AP029              AP29_36F.
       AP030              AP29_36F.
       AP031              AP29_36F.
       AP032              AP29_36F.
       AP033              AP29_36F.
       AP034              AP29_36F.
       AP035              AP29_36F.
       AP036              AP29_36F.
       AP037              AP37_43F.
       AP038              AP37_43F.
       AP039              AP37_43F.
       AP040              AP37_43F.
       AP041              AP37_43F.
       AP042              AP37_43F.
       AP043              AP37_43F.
       AP044              AP044F.
       AP045              AP45_46F.
       AP046              AP45_46F.
       AP047              AP047F.
       AP048              AP048F.
       AP049              AP049F.
       AP050              AP50_52F.
       AP051              AP50_52F.
       AP052              AP50_52F.
       AP053              AP053F.
       AP054              AP054F.
 ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;


   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(54)
                AP001 AP002 AP003 AP004 AP005 AP006 AP007 AP008 AP009 AP010
                AP011 AP012 AP013 AP014 AP015 AP016 AP017 AP018 AP019 AP020
                AP021 AP022 AP023 AP024 AP025 AP026 AP027 AP028 AP029 AP030
                AP031 AP032 AP033 AP034 AP035 AP036 AP037 AP038 AP039 AP040
                AP041 AP042 AP043 AP044 AP045 AP046 AP047 AP048 AP049 AP050
                AP051 AP052 AP053 AP054;
   DO  i=1 TO 54;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;


   drop i;
RUN;
